#pragma interface
#ifndef usermenu_h
#define usermenu_h
#ifndef MISC_H
    #include <misc.h>
#endif
#ifndef MODULE_H
    #include <module.h>
#endif

#include <modapi_def.h>
#include <modapi.h>
class MODULE_usermenu: public LINUXCONF_MODULE{
    /*~PROTOBEG~ MODULE_usermenu */
public:
	MODULE_usermenu (void);
	int dohtml (const char *key);
	int domenu (MENU_CONTEXT context,
		 const char *key);
	int execmain (int argc, char *argv[], bool);
	int message (const char *msg,
		 int ,
		 const char *[]);
	void setmenu (DIALOG&dia,
		 MENU_CONTEXT context);
	void usage (SSTRINGS&tb);
    /*~PROTOEND~ MODULE_usermenu */
};

extern const char K_USERMENU[];


#include "usermenu.p"

#endif
